@@ -20,18 +20,11 @@
 
 import datetime
 
-from google.protobuf.message import Message
 from kegbot.util import util
 
-try:
-  from django.conf import settings
-  TIME_ZONE = settings.TIME_ZONE
-except ImportError:
-  TIME_ZONE = 'America/Los_Angeles'
+TIME_ZONE = 'UTC'
 
 def ProtoMessageToDict(message):
-  if not isinstance(message, Message):
-    message = ToProto(message, full=True)
   ret = util.AttrDict()
   #if not message.IsInitialized():
   #  raise ValueError, 'Message not initialized'
